<?php

/**
 * @file
 */

/**
 * This hooks allows us to update parameters which will allow us to decide to
 * display or not the Password Policy status table on user password form
 * elements.
 *
 * The example code below allows Password Policy to work with the User
 * Registration Password module.
 *
 * @param array $visible_params
 *   The parameters array containing information that will allow us to decide to
 *   display or not the Password Policy status table.
 *
 * @return void
 */
function hook_password_policy_table_should_be_visible_alter(array &$visible_params) {

  $current_user_roles = $visible_params['user_roles'];

  $urp_settings = \Drupal::config('user_registrationpassword.settings');
  if (!empty($urp_settings)) {
    $registration = $urp_settings->get('registration');
    $verify_email_before_password = ($registration === 'default');
    if (!$verify_email_before_password && \Drupal::currentUser()->isAnonymous()) {
      // Before a user has registered all they have is the anonymous role,
      // which can't be targeted by a password policy rule. So also search
      // for the authenticated role, which every user will have post register.
      $current_user_roles[] = "authenticated";
    }
  }

  $visible_params['verify_email_before_password'] = $verify_email_before_password;
  $visible_params['user_roles'] = $current_user_roles;
}

/**
 * This hooks allows us to update parameters which will allow us to decide to
 * run or not the Password Policy validation on user password form elements.
 *
 * The example code below allows Password Policy to work with the User
 * Registration Password module.
 *
 * @param array $validation_params
 *   The parameters array containing information that will allow us to decide to
 *   validate or not the Password Policy on password elements.
 *
 * @return void
 */
function hook_password_policy_validation_should_run_alter(array &$validation_params) {

  $urp_settings = \Drupal::config('user_registrationpassword.settings');
  if (!empty($urp_settings)) {
    $registration = $urp_settings->get('registration');
    $verify_email_before_password = ($registration === 'default');
  }

  $validation_params['verify_email_before_password'] = $verify_email_before_password;
}
