<?php

namespace Drupal\password_policy_extras\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class PasswordPolicyExtrasSettingsForm.
 * The config form for the password_policy_extras module.
 *
 * @package Drupal\htcacheclean\Form
 */
class PasswordPolicyExtrasSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'password_policy_extras_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['password_policy_extras.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('password_policy_extras.settings');

    $form['disable_ajax_progress'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable Ajax throbber'),
      '#default_value' => $config->get('disable_ajax_progress'),
    ];

    $form['failed_messages_only'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display failed messages only'),
      '#default_value' => $config->get('failed_messages_only'),
    ];

    $form['hide_password_suggestions'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide default Drupal password suggestions'),
      '#default_value' => $config->get('hide_password_suggestions'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('password_policy_extras.settings');

    $config
      ->set('disable_ajax_progress', $form_state->getValue('disable_ajax_progress'))
      ->set('failed_messages_only', $form_state->getValue('failed_messages_only'))
      ->set('hide_password_suggestions', $form_state->getValue('hide_password_suggestions'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
