<?php

namespace Drupal\password_policy_extras;

use Drupal\password_policy\PasswordPolicyValidationManager;

/**
 * Class PasswordPolicyExtrasValidationManager.
 *
 * Decide whether to display validation and whether to validate a password.
 *
 * @package Drupal\password_policy_extras
 */
class PasswordPolicyExtrasValidationManager extends PasswordPolicyValidationManager {

  /**
   * {@inheritdoc}
   */
  public function tableShouldBeVisible() {

    $user_roles = $this->currentUser->getRoles();
    $verify_email_before_password = $this->userSettingsConfig->get('verify_mail');
    $is_route_without_password = ($this->routeMatch->getRouteName() !== 'user.reset');

    $visible_params = [
      'verify_email_before_password' => $verify_email_before_password,
      'is_route_without_password' => $is_route_without_password,
      'user_roles' => $user_roles
    ];

    \Drupal::moduleHandler()->alter(
      'password_policy_table_should_be_visible', $visible_params);

    if ($this->currentUser->isAnonymous()
      && $visible_params['verify_email_before_password']
      && $visible_params['is_route_without_password']) {
      return FALSE;
    }

    $role_applies = $this->passwordPolicyStorage->getQuery()
      ->condition('roles.*', $visible_params['user_roles'], 'IN')
      ->condition('show_policy_table', TRUE)
      ->accessCheck(FALSE)
      ->execute();
    return !empty($role_applies);
  }

  /**
   * {@inheritdoc}
   */
  public function validationShouldRun() {

    $user_roles = $this->currentUser->getRoles();
    if (!in_array('authenticated', $user_roles)) {
      // Before a user has registered all they have is the anonymous role,
      // which can't be targeted by a password policy rule. So also search
      // for the authenticated role, which every user will have post register.
      $user_roles[] = 'authenticated';
    }
    $verify_email_before_password = $this->userSettingsConfig->get('verify_mail');
    $is_route_without_password = ($this->routeMatch->getRouteName() !== 'user.reset');

    $validation_params = [
      'verify_email_before_password' => $verify_email_before_password,
      'is_route_without_password' => $is_route_without_password,
      'user_roles' => $user_roles
    ];

    \Drupal::moduleHandler()->alter(
      'password_policy_validation_should_run', $validation_params);

    if ($this->currentUser->isAnonymous()
      && $validation_params['verify_email_before_password']
      && $validation_params['is_route_without_password']) {
      return FALSE;
    }

    $role_applies = $this->passwordPolicyStorage->getQuery()
      ->condition('roles.*', $validation_params['user_roles'], 'IN')
      ->accessCheck(FALSE)
      ->execute();
    return !empty($role_applies);
  }

}
